@@ -1,4 +1,6 @@
 package _NotShownSubClass;
+use warnings;
+use strict;
 use base '_NotShownBaseClass';
 
 sub in_sub_class {
